# Noggin messages

A schema package for [Noggin](https://github.com/fedora-infra/noggin).

See the [detailed documentation](https://fedora-messaging.readthedocs.io/en/latest/messages.html) on packaging your schemas.

![PyPI](https://img.shields.io/pypi/v/noggin-messages.svg)
![Supported Python versions](https://img.shields.io/pypi/pyversions/noggin-messages.svg)
![Build status](https://github.com/fedora-infra/noggin-messages/actions/workflows/main.yml/badge.svg?branch=dev)
